@@ -7,13 +7,13 @@ from . import multi_jobs
 import math
 from . import progress_bar
 from . import Reslib
-from .calc_utils import BorderCheck,SortFitness,SortPosition,check_listitem,record_check,record_checkMV
+from .calc_utils import BorderChecker,SortFitness,SortPosition,check_listitem,record_check,record_checkMV
 from .calc_utils import CalculateFitness,CalculateFitnessMP,CalculateFitness_MV,CalculateFitnessMP_MV
 
 Sampling = "LHS"
 EliteOppoSwitch = True # Switch for elite opposition based optimization
 OppoFactor = 0.1 # The proportion of the samples to do the elite opposition operation
-
+BorderCheckMethod = "rebound"
 
 def initial(pop, dim, ub, lb):
     """
@@ -111,6 +111,7 @@ def run(pop, dim, lb, ub, MaxIter, fun,RecordPath = None, args=()):
     print("Lower Bnd.:{}".format(lb))
     print("Upper Bnd.:{}".format(ub))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     if not RecordPath:
         iter = 0
         hs = []
@@ -210,7 +211,7 @@ def run(pop, dim, lb, ub, MaxIter, fun,RecordPath = None, args=()):
                 X[i, j] = (X1 + X2 + X3) / 3
 
 
-        X = BorderCheck(X, ub, lb, pop, dim)
+        X = checker.BorderCheck(X, ub, lb, pop, dim)
         fitness, res = CalculateFitness(X, fun,1, args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
@@ -232,7 +233,7 @@ def run(pop, dim, lb, ub, MaxIter, fun,RecordPath = None, args=()):
                 Tub = np.max(XElite, 0)
                 # update the elite opposition solutions
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
-                XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
+                XOppo = checker.BorderCheck(XOppo, ub, lb, EliteNumber, dim)
                 fitOppo, resOppo = CalculateFitness(XOppo, fun,1, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
@@ -318,6 +319,7 @@ def runMP(pop, dim, lb, ub, MaxIter,fun, n_jobs,RecordPath = None,args=()):
     print("Lower Bnd.:{}".format(lb))
     print("Upper Bnd.:{}".format(ub))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     if not RecordPath:
         iter = 0
         hs = []
@@ -416,7 +418,7 @@ def runMP(pop, dim, lb, ub, MaxIter,fun, n_jobs,RecordPath = None,args=()):
 
                 X[i, j] = (X1 + X2 + X3) / 3
 
-        X = BorderCheck(X, ub, lb, pop, dim)
+        X = checker.BorderCheck(X, ub, lb, pop, dim)
         fitness, res = CalculateFitnessMP(X, fun,1,n_jobs, args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
@@ -437,7 +439,7 @@ def runMP(pop, dim, lb, ub, MaxIter,fun, n_jobs,RecordPath = None,args=()):
                 Tub = np.max(XElite, 0)
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
-                XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
+                XOppo = checker.BorderCheck(XOppo, ub, lb, EliteNumber, dim)
                 fitOppo, resOppo = CalculateFitnessMP(XOppo, fun,1, n_jobs, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
@@ -510,6 +512,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter,  fun,RecordPath = None, args=()):
     print("Lower Bnd.:{}".format(lbs))
     print("Upper Bnd.:{}".format(ubs))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     num_var = len(dims)
     if not RecordPath:
         iter = 0
@@ -615,7 +618,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter,  fun,RecordPath = None, args=()):
 
 
         for n in range(num_var):
-            X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
+            X[n] = checker.BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
         fitness, res = CalculateFitness_MV(X, fun, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
@@ -638,7 +641,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter,  fun,RecordPath = None, args=()):
 
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
-                    XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
+                    XOppo[n] = checker.BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
                 fitOppo, resOppo = CalculateFitness_MV(XOppo, fun, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
@@ -721,6 +724,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter,  fun,n_jobs,RecordPath = None, args=(
     print("Lower Bnd.:{}".format(lbs))
     print("Upper Bnd.:{}".format(ubs))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     num_var = len(dims)
     if not RecordPath:
         iter = 0
@@ -824,7 +828,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter,  fun,n_jobs,RecordPath = None, args=(
                     X[n][i, j] = (X1 + X2 + X3) / 3
 
         for n in range(num_var):
-            X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
+            X[n] = checker.BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
         fitness, res = CalculateFitnessMP_MV(X, fun,n_jobs, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
@@ -847,7 +851,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter,  fun,n_jobs,RecordPath = None, args=(
 
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
-                    XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
+                    XOppo[n] = checker.BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
                 fitOppo, resOppo = CalculateFitnessMP_MV(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
