@@ -7,12 +7,13 @@ from . import multi_jobs
 import math
 from . import progress_bar
 from . import Reslib
-from .calc_utils import BorderCheck,SortFitness,SortPosition,check_listitem,record_check,record_checkMV
+from .calc_utils import BorderChecker,SortFitness,SortPosition,check_listitem,record_check,record_checkMV
 from .calc_utils import CalculateFitness,CalculateFitnessMP,CalculateFitness_MV,CalculateFitnessMP_MV
 
 Sampling = "LHS"
 EliteOppoSwitch = True
 OppoFactor = 0.1
+BorderCheckMethod = "rebound"
 
 
 def initial(pop, dim, ub, lb):
@@ -115,6 +116,7 @@ def run(pop, dim, lb, ub, MaxIter,  fun,RecordPath = None, args=()):
     print("Lower Bnd.:{}".format(lb))
     print("Upper Bnd.:{}".format(ub))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     if not RecordPath:
         iter = 0
         hs = []
@@ -181,7 +183,7 @@ def run(pop, dim, lb, ub, MaxIter,  fun,RecordPath = None, args=()):
                     X[i, j] = distance_to_flame * np.exp(b * r) * np.cos(r * 2 * math.pi) + Xs[Flame_no-1, j]
 
 
-        X = BorderCheck(X, ub, lb, pop, dim)
+        X = checker.BorderCheck(X, ub, lb, pop, dim)
         fitness, res = CalculateFitness(X, fun,1, args)
 
         # merge the flame and moth
@@ -209,7 +211,7 @@ def run(pop, dim, lb, ub, MaxIter,  fun,RecordPath = None, args=()):
                 Tlb = np.min(XElite, 0)
                 Tub = np.max(XElite, 0)
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
-                XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
+                XOppo = checker.BorderCheck(XOppo, ub, lb, EliteNumber, dim)
                 fitOppo, resOppo = CalculateFitness(XOppo, fun,1, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitnessS[j]:
@@ -295,6 +297,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs,RecordPath = None, args=()):
     print("Lower Bnd.:{}".format(lb))
     print("Upper Bnd.:{}".format(ub))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     if not RecordPath:
         iter = 0
         hs = []
@@ -357,7 +360,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs,RecordPath = None, args=()):
                     r = (a - 1) * random.random() + 1
                     X[i, j] = distance_to_flame * np.exp(b * r) * np.cos(r * 2 * math.pi) + Xs[Flame_no - 1, j]
 
-        X = BorderCheck(X, ub, lb, pop, dim)
+        X = checker.BorderCheck(X, ub, lb, pop, dim)
         fitness, res = CalculateFitnessMP(X, fun,1,n_jobs, args)
         fitnessM = np.concatenate([fitnessS, fitness], axis=0)
         Xm = np.concatenate([Xs, X], axis=0)
@@ -379,7 +382,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs,RecordPath = None, args=()):
                 Tub = np.max(XElite, 0)
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
-                XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
+                XOppo = checker.BorderCheck(XOppo, ub, lb, EliteNumber, dim)
                 fitOppo, resOppo = CalculateFitnessMP(XOppo, fun,1,n_jobs, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitnessS[j]:
@@ -452,6 +455,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
     print("Lower Bnd.:{}".format(lbs))
     print("Upper Bnd.:{}".format(ubs))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     num_var = len(dims)
     if not RecordPath:
         iter = 0
@@ -524,7 +528,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
                         X[n][i, j] = distance_to_flame * np.exp(b * r) * np.cos(r * 2 * math.pi) + Xs[n][Flame_no-1, j]
 
         for n in range(num_var):
-            X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
+            X[n] = checker.BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
         fitness, res = CalculateFitness_MV(X, fun, args)
 
         for n in range(num_var):
@@ -549,7 +553,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
 
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
-                    XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
+                    XOppo[n] = checker.BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
                 fitOppo, resOppo = CalculateFitness_MV(XOppo, fun, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
@@ -634,6 +638,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
     print("Lower Bnd.:{}".format(lbs))
     print("Upper Bnd.:{}".format(ubs))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     num_var = len(dims)
     if not RecordPath:
         iter = 0
@@ -705,7 +710,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
                         X[n][i, j] = distance_to_flame * np.exp(b * r) * np.cos(r * 2 * math.pi) + Xs[n][Flame_no-1, j]
 
         for n in range(num_var):
-            X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
+            X[n] = checker.BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
         fitness, res = CalculateFitnessMP_MV(X, fun,n_jobs, args)
 
         for n in range(num_var):
@@ -730,7 +735,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun,n_jobs,RecordPath = None, args=()
 
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
-                    XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
+                    XOppo[n] = checker.BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
                 fitOppo, resOppo = CalculateFitnessMP_MV(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
