@@ -7,7 +7,7 @@ from . import multi_jobs
 import math
 from . import progress_bar
 from . import Reslib
-from .calc_utils import BorderCheck,SortFitness,SortPosition,check_listitem,record_check,record_checkMV
+from .calc_utils import BorderChecker,SortFitness,SortPosition,check_listitem,record_check,record_checkMV
 from .calc_utils import CalculateFitness,CalculateFitnessMP,CalculateFitness_MV,CalculateFitnessMP_MV
 
 EliteOppoSwitch = True # Switch for elite opposition based learning
@@ -15,6 +15,8 @@ OppoFactor = 0.1 # proportion of samples to do the elite opposition operation
 ST = 0.6 # parameter, changeable
 PD = 0.7 # parameter, changeable
 Sampling = "LHS"
+BorderCheckMethod = "rebound"
+
 
 def initial(pop, dim, ub, lb):
     """
@@ -193,6 +195,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None, args=()):
     print("Lower Bnd.:{}".format(lb))
     print("Upper Bnd.:{}".format(ub))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     PDNumber = int(pop * PD)
     SDNumber = int(pop - pop * PD)
     if not RecordPath:
@@ -246,7 +249,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None, args=()):
         X = SDUpdate(X, pop, SDNumber, fitness, BestF)
 
 
-        X = BorderCheck(X, ub, lb, pop, dim)
+        X = checker.BorderCheck(X, ub, lb, pop, dim)
         fitness, res = CalculateFitness(X, fun, 1,args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
@@ -267,7 +270,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None, args=()):
                 Tub = np.max(XElite, 0)
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
-                XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
+                XOppo = checker.BorderCheck(XOppo, ub, lb, EliteNumber, dim)
                 fitOppo, resOppo = CalculateFitness(XOppo, fun,1, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
@@ -352,6 +355,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs, RecordPath = None, args=()):
     print("Lower Bnd.:{}".format(lb))
     print("Upper Bnd.:{}".format(ub))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     PDNumber = int(pop * PD)
     SDNumber = int(pop - pop * PD)
     if not RecordPath:
@@ -405,7 +409,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs, RecordPath = None, args=()):
         X = SDUpdate(X, pop, SDNumber, fitness, BestF)
 
 
-        X = BorderCheck(X, ub, lb, pop, dim)
+        X = checker.BorderCheck(X, ub, lb, pop, dim)
         fitness, res = CalculateFitnessMP(X, fun,1, n_jobs, args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
@@ -426,7 +430,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun, n_jobs, RecordPath = None, args=()):
                 Tub = np.max(XElite, 0)
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
-                XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
+                XOppo = checker.BorderCheck(XOppo, ub, lb, EliteNumber, dim)
                 fitOppo, resOppo = CalculateFitnessMP(XOppo, fun,1, n_jobs, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
@@ -499,6 +503,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
     print("Lower Bnd.:{}".format(lbs))
     print("Upper Bnd.:{}".format(ubs))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     num_var = len(dims)
     PDNumber = int(pop * PD)
     SDNumber = int(pop - pop * PD)
@@ -559,7 +564,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
             X[n] = SDUpdate(X[n], pop, SDNumber, fitness[n], BestF)
 
         for n in range(num_var):
-            X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
+            X[n] = checker.BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
         fitness, res = CalculateFitness_MV(X, fun, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
@@ -583,7 +588,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None, args=()):
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)])
                          for n in range(num_var)]
                 for n in range(num_var):
-                    XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
+                    XOppo[n] = checker.BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
                 fitOppo, resOppo = CalculateFitness_MV(XOppo, fun, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
@@ -664,6 +669,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun, n_jobs,RecordPath = None, args=(
     print("Lower Bnd.:{}".format(lbs))
     print("Upper Bnd.:{}".format(ubs))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     num_var = len(dims)
     PDNumber = int(pop * PD)
     SDNumber = int(pop - pop * PD)
@@ -723,7 +729,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun, n_jobs,RecordPath = None, args=(
 
 
         for n in range(num_var):
-            X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
+            X[n] = checker.BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
         fitness, res = CalculateFitnessMP_MV(X, fun, n_jobs, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
@@ -747,7 +753,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter, fun, n_jobs,RecordPath = None, args=(
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)])
                          for n in range(num_var)]
                 for n in range(num_var):
-                    XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
+                    XOppo[n] = checker.BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
                 fitOppo, resOppo = CalculateFitnessMP_MV(XOppo, fun, n_jobs, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
