@@ -7,12 +7,14 @@ from . import multi_jobs
 import math
 from . import progress_bar
 from . import Reslib
-from .calc_utils import BorderCheck,SortFitness,SortPosition,check_listitem,record_check,record_checkMV
+from .calc_utils import BorderChecker,SortFitness,SortPosition,check_listitem,record_check,record_checkMV
 from .calc_utils import CalculateFitness,CalculateFitnessMP,CalculateFitness_MV,CalculateFitnessMP_MV
 
 EliteOppoSwitch = True # Switch for elite opposition based learning
 OppoFactor = 0.1 # proportion of samples to do the elite opposition operation
 Sampling = "LHS"
+BorderCheckMethod = "rebound"
+
 
 def initial(pop, dim, ub, lb):
     """
@@ -109,6 +111,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None,args=()):
     print("Lower Bnd.:{}".format(lb))
     print("Upper Bnd.:{}".format(ub))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     if not RecordPath:
         iter = 0
         hs = []
@@ -179,7 +182,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None,args=()):
                     X[i, j] = distance2Leader * np.exp(b * l) * np.cos(l * 2 * math.pi) + Leader[j]
 
 
-        X = BorderCheck(X, ub, lb, pop, dim)
+        X = checker.BorderCheck(X, ub, lb, pop, dim)
         fitness,res = CalculateFitness(X, fun,1,args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
@@ -200,7 +203,7 @@ def run(pop, dim, lb, ub, MaxIter, fun, RecordPath = None,args=()):
                 Tub = np.max(XElite, 0)
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
-                XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
+                XOppo = checker.BorderCheck(XOppo, ub, lb, EliteNumber, dim)
                 fitOppo, resOppo = CalculateFitness(XOppo, fun,1, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
@@ -285,6 +288,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, RecordPath = None,args=()):
     print("Lower Bnd.:{}".format(lb))
     print("Upper Bnd.:{}".format(ub))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     if not RecordPath:
         iter = 0
         hs = []
@@ -355,7 +359,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, RecordPath = None,args=()):
                     X[i, j] = distance2Leader * np.exp(b * l) * np.cos(l * 2 * math.pi) + Leader[j]
 
 
-        X = BorderCheck(X, ub, lb, pop, dim)
+        X = checker.BorderCheck(X, ub, lb, pop, dim)
         fitness,res = CalculateFitnessMP(X, fun,1,n_jobs,args)
         fitness, sortIndex = SortFitness(fitness)
         X = SortPosition(X, sortIndex)
@@ -376,7 +380,7 @@ def runMP(pop, dim, lb, ub, MaxIter, fun,n_jobs, RecordPath = None,args=()):
                 Tub = np.max(XElite, 0)
 
                 XOppo = np.array([random.random() * (Tlb + Tub) - XElite[j, :] for j in range(EliteNumber)])
-                XOppo = BorderCheck(XOppo, ub, lb, EliteNumber, dim)
+                XOppo = checker.BorderCheck(XOppo, ub, lb, EliteNumber, dim)
                 fitOppo, resOppo = CalculateFitnessMP(XOppo, fun,1, n_jobs, args)
                 for j in range(EliteNumber):
                     if fitOppo[j] < fitness[j]:
@@ -447,6 +451,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None,args=()):
     print("Lower Bnd.:{}".format(lbs))
     print("Upper Bnd.:{}".format(ubs))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     num_var = len(dims)
     if not RecordPath:
         iter = 0
@@ -525,7 +530,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None,args=()):
                         X[n][i, j] = distance2Leader * np.exp(b * l) * np.cos(l * 2 * math.pi) + Leader[n][j]
 
         for n in range(num_var):
-            X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
+            X[n] = checker.BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
         fitness, res = CalculateFitness_MV(X, fun, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
@@ -548,7 +553,7 @@ def run_MV(pop, dims, lbs, ubs, MaxIter, fun,RecordPath = None,args=()):
 
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
-                    XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
+                    XOppo[n] = checker.BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
                 fitOppo, resOppo = CalculateFitness_MV(XOppo, fun, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
@@ -629,6 +634,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter,fun,n_jobs,RecordPath = None,args=()):
     print("Lower Bnd.:{}".format(lbs))
     print("Upper Bnd.:{}".format(ubs))
     Progress_Bar = progress_bar.ProgressBar(MaxIter + 1)
+    checker = BorderChecker(method=BorderCheckMethod)
     num_var = len(dims)
     if not RecordPath:
         iter = 0
@@ -707,7 +713,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter,fun,n_jobs,RecordPath = None,args=()):
 
 
         for n in range(num_var):
-            X[n] = BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
+            X[n] = checker.BorderCheck(X[n], ubs[n], lbs[n], pop, dims[n])
         fitness, res = CalculateFitnessMP_MV(X, fun,n_jobs, args)
         for n in range(num_var):
             fitness[n], sortIndex = SortFitness(fitness[n])
@@ -730,7 +736,7 @@ def runMP_MV(pop, dims, lbs, ubs, MaxIter,fun,n_jobs,RecordPath = None,args=()):
 
                 XOppo = [np.array([random.random() * (Tlb[n] + Tub[n]) - XElite[n][j, :] for j in range(EliteNumber)]) for n in range(num_var)]
                 for n in range(num_var):
-                    XOppo[n] = BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
+                    XOppo[n] = checker.BorderCheck(XOppo[n], ubs[n], lbs[n], EliteNumber, dims[n])
                 fitOppo, resOppo = CalculateFitnessMP_MV(XOppo, fun,n_jobs, args)
                 for j in range(EliteNumber):
                     for n in range(num_var):
