@@ -22,10 +22,11 @@ from . import utilize
 from . import TOPSIS
 from . import Reslib
 from . import calc_utils
+from . import integrate
 
 
 
 __all__ = ['evaluation_metrics','utilize', 'multi_jobs','plot','progress_bar',
            'sampling','save','test_functions','uncertainty_analysis_fun',
            'WOA','TSA','SCA','SOA','SSA','PSO','GLUE','GWO','MFO',
-           'MOPSO','MODE','NSGA2','template', 'TOPSIS',"Reslib","calc_utils"]
\ No newline at end of file
+           'MOPSO','MODE','NSGA2','template', 'TOPSIS',"Reslib","calc_utils","integrate"]
\ No newline at end of file
